@@ -2,32 +2,33 @@
  * NVIDIA CUDA Debugger CUDA-GDB
  * Copyright (C) 2007-2025 NVIDIA Corporation
  * Written by CUDA-GDB team at NVIDIA <cudatools@nvidia.com>
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 3 as
  * published by the Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "defs.h"
-#include <stdbool.h>
-#include <string>
+
+#include "cuda-context.h"
+#include "cuda-events.h"
+#include "cuda-options.h"
+#include "cuda-packet-manager.h"
+#include "cuda-state.h"
+#include "cuda-utils.h"
 #include "gdbthread.h"
 #include "inferior.h"
 #include "remote.h"
-#include "cuda-packet-manager.h"
-#include "cuda-context.h"
-#include "cuda-events.h"
-#include "cuda-state.h"
-#include "cuda-utils.h"
-#include "cuda-options.h"
+#include <stdbool.h>
+#include <string>
 
 #include "gdbsupport/rsp-low.h"
 
@@ -39,11 +40,11 @@
    packed/unpacked by the pdebug putpkt/getpkt functions.
 
    Until then, use pdebug max allowed size.
-   Each DS_DATA_MAX_SIZE can be escaped (*2), 2 frame chars (+2) plus a checksum
-   that can be escaped (+2). */
-# define PBUFSIZE (DS_DATA_MAX_SIZE * 2 + 4)
+   Each DS_DATA_MAX_SIZE can be escaped (*2), 2 frame chars (+2) plus a
+   checksum that can be escaped (+2). */
+#define PBUFSIZE (DS_DATA_MAX_SIZE * 2 + 4)
 #else
-# define PBUFSIZE 16384
+#define PBUFSIZE 16384
 #endif
 
 struct cuda_remote_callbacks : public send_remote_packet_callbacks
@@ -125,7 +126,8 @@ public:
     /* Allow for one final lookup to grab the ending data */
     if (pos == std::string::npos && m_recv_pos == std::string::npos)
       error (_ ("The data in the cuda packet is not complete (cuda-gdb).\n"));
-    if (((pos == std::string::npos ? m_recv_buf.size () : pos) - m_recv_pos) < size)
+    if (((pos == std::string::npos ? m_recv_buf.size () : pos) - m_recv_pos)
+	< size)
       error (_ ("The data in the cuda packet is not complete (cuda-gdb).\n"));
 
     /* Extract binary data */
@@ -169,7 +171,7 @@ static void
 cuda_remote_send_packet (cuda_packet_type_t packet_type)
 {
   remote_callbacks.append_string ("qnv.");
-  remote_callbacks.append_bin ((gdb_byte *) &packet_type, sizeof (packet_type));
+  remote_callbacks.append_bin ((gdb_byte *)&packet_type, sizeof (packet_type));
 
   remote_callbacks.send_request ();
 }
@@ -178,7 +180,7 @@ static bool
 cuda_remote_get_return_value ()
 {
   bool ret_val;
-  remote_callbacks.extract_bin ((gdb_byte *) &ret_val, sizeof (ret_val));
+  remote_callbacks.extract_bin ((gdb_byte *)&ret_val, sizeof (ret_val));
 
   return ret_val;
 }
@@ -214,7 +216,8 @@ cuda_remote_notification_analyze (ptid_t ptid, struct target_waitstatus *ws)
      the thread that triggered this code path.  */
   if (inferior_ptid == null_ptid)
     {
-      struct thread_info *tp = current_inferior ()->process_target ()->find_thread (ptid);
+      struct thread_info *tp
+	  = current_inferior ()->process_target ()->find_thread (ptid);
       if (tp != nullptr)
 	trap_expected = tp->control.trap_expected;
     }
@@ -226,7 +229,7 @@ cuda_remote_notification_analyze (ptid_t ptid, struct target_waitstatus *ws)
 
   remote_callbacks.append_string ("qnv.");
   cuda_packet_type_t packet_type = NOTIFICATION_ANALYZE;
-  remote_callbacks.append_bin ((gdb_byte *) &packet_type, sizeof (packet_type));
+  remote_callbacks.append_bin ((gdb_byte *)&packet_type, sizeof (packet_type));
   remote_callbacks.append_separator ();
 #ifdef __QNXTARGET__
   /* We only send the wait status for QNX as we don't have an easy way of
@@ -236,7 +239,8 @@ cuda_remote_notification_analyze (ptid_t ptid, struct target_waitstatus *ws)
   remote_callbacks.append_bin ((gdb_byte *)ws, sizeof (*ws));
   remote_callbacks.append_separator ();
 #endif
-  remote_callbacks.append_bin ((gdb_byte *)&trap_expected, sizeof (trap_expected));
+  remote_callbacks.append_bin ((gdb_byte *)&trap_expected,
+			       sizeof (trap_expected));
 
   remote_callbacks.send_request ();
 }
@@ -254,19 +258,23 @@ cuda_remote_notification_consume_pending ()
 }
 
 template <typename TValue>
-using FnPerWarpUpdateGet = void (*)(uint32_t dev, uint32_t sm, uint32_t wp, TValue *value);
+using FnPerWarpUpdateGet
+    = void (*) (uint32_t dev, uint32_t sm, uint32_t wp, TValue *value);
 template <typename TValue>
-using FnPerWarpUpdateSet = void (*)(uint32_t dev, uint32_t sm, uint32_t wp, const TValue& value);
+using FnPerWarpUpdateSet
+    = void (*) (uint32_t dev, uint32_t sm, uint32_t wp, const TValue &value);
 
 template <typename TValue>
 void
 cuda_remote_update_per_warp_info_in_sm (uint32_t dev, uint32_t sm,
-  cuda_packet_type_t packet_type, const char* name,
-  FnPerWarpUpdateGet<TValue>&& get_value, FnPerWarpUpdateSet<TValue>&& set_value)
+					cuda_packet_type_t packet_type,
+					const char *name,
+					FnPerWarpUpdateGet<TValue> &&get_value,
+					FnPerWarpUpdateSet<TValue> &&set_value)
 {
 #ifdef __QNXTARGET__
   uint32_t wp;
-  const cuda_api_warpmask* valid_warps_mask_c;
+  const cuda_api_warpmask *valid_warps_mask_c;
   cuda_api_warpmask valid_warps_mask_s;
   uint32_t num_warps;
   TValue value;
@@ -285,46 +293,48 @@ cuda_remote_update_per_warp_info_in_sm (uint32_t dev, uint32_t sm,
   for (wp = 0; wp < num_warps; wp++)
     {
       if (cuda_state::warp_valid (dev, sm, wp))
-        {
-          /* Get the value from the API first, then store it in warp state. */
-          get_value (dev, sm, wp, &value);
-          set_value (dev, sm, wp, value);
-        }
+	{
+	  /* Get the value from the API first, then store it in warp state. */
+	  get_value (dev, sm, wp, &value);
+	  set_value (dev, sm, wp, value);
+	}
     }
 #else
-  const cuda_api_warpmask* valid_warps_mask_c = cuda_state::sm_get_valid_warps_mask (dev, sm);
+  const cuda_api_warpmask *valid_warps_mask_c
+      = cuda_state::sm_get_valid_warps_mask (dev, sm);
   uint32_t num_warps = cuda_state::device_get_num_warps (dev);
 
   remote_callbacks.append_string ("qnv.");
-  remote_callbacks.append_bin ((gdb_byte *) &packet_type, sizeof (packet_type));
+  remote_callbacks.append_bin ((gdb_byte *)&packet_type, sizeof (packet_type));
   remote_callbacks.append_separator ();
-  remote_callbacks.append_bin ((gdb_byte *) &dev, sizeof (dev));
+  remote_callbacks.append_bin ((gdb_byte *)&dev, sizeof (dev));
   remote_callbacks.append_separator ();
-  remote_callbacks.append_bin ((gdb_byte *) &sm, sizeof (sm));
+  remote_callbacks.append_bin ((gdb_byte *)&sm, sizeof (sm));
   remote_callbacks.append_separator ();
-  remote_callbacks.append_bin ((gdb_byte *) &num_warps, sizeof (num_warps));
+  remote_callbacks.append_bin ((gdb_byte *)&num_warps, sizeof (num_warps));
   remote_callbacks.append_separator ();
 
   remote_callbacks.send_request ();
 
   cuda_api_warpmask valid_warps_mask_s;
-  remote_callbacks.extract_bin ((gdb_byte *) &valid_warps_mask_s, sizeof (valid_warps_mask_s));
+  remote_callbacks.extract_bin ((gdb_byte *)&valid_warps_mask_s,
+				sizeof (valid_warps_mask_s));
   gdb_assert (valid_warps_mask_s == valid_warps_mask_c);
 
   for (uint32_t wp = 0; wp < num_warps; wp++)
     {
       if (cuda_state::warp_valid (dev, sm, wp))
-        {
+	{
 	  TValue value;
-	  remote_callbacks.extract_bin ((gdb_byte *) &value, sizeof (value));
-          set_value (dev, sm, wp, value);
-        }
+	  remote_callbacks.extract_bin ((gdb_byte *)&value, sizeof (value));
+	  set_value (dev, sm, wp, value);
+	}
     }
 
   CUDBGResult res;
-  remote_callbacks.extract_bin ((gdb_byte *) &res, sizeof (res));
+  remote_callbacks.extract_bin ((gdb_byte *)&res, sizeof (res));
   if (res != CUDBG_SUCCESS)
-    error (_("Error: Failed to read %s (error=%u).\n"), name, res);
+    error (_ ("Error: Failed to read %s (error=%u).\n"), name, res);
 #endif
 }
 
@@ -332,87 +342,97 @@ void
 cuda_remote_update_grid_id_in_sm (uint32_t dev, uint32_t sm)
 {
   cuda_remote_update_per_warp_info_in_sm<uint64_t> (
-    dev, sm, UPDATE_GRID_ID_IN_SM, "grid ID", cuda_debugapi::read_grid_id,
-    [](uint32_t _dev, uint32_t _sm, uint32_t _wp, const uint64_t& _grid_id) {
-      cuda_state::warp_set_grid_id (_dev, _sm, _wp, _grid_id);
-    });
+      dev, sm, UPDATE_GRID_ID_IN_SM, "grid ID", cuda_debugapi::read_grid_id,
+      [] (uint32_t _dev, uint32_t _sm, uint32_t _wp,
+	  const uint64_t &_grid_id) {
+	cuda_state::warp_set_grid_id (_dev, _sm, _wp, _grid_id);
+      });
 }
 
 void
 cuda_remote_update_cluster_idx_in_sm (uint32_t dev, uint32_t sm)
 {
   cuda_remote_update_per_warp_info_in_sm<CuDim3> (
-    dev, sm, UPDATE_CLUSTER_IDX_IN_SM, "cluster index", cuda_debugapi::read_cluster_idx,
-    [](uint32_t _dev, uint32_t _sm, uint32_t _wp, const CuDim3& _cluster_idx) {
-      cuda_state::warp_set_cluster_idx (_dev, _sm, _wp, _cluster_idx);
-    });
+      dev, sm, UPDATE_CLUSTER_IDX_IN_SM, "cluster index",
+      cuda_debugapi::read_cluster_idx,
+      [] (uint32_t _dev, uint32_t _sm, uint32_t _wp,
+	  const CuDim3 &_cluster_idx) {
+	cuda_state::warp_set_cluster_idx (_dev, _sm, _wp, _cluster_idx);
+      });
 }
 
 void
 cuda_remote_update_cluster_dim_in_sm (uint32_t dev, uint32_t sm)
 {
   cuda_remote_update_per_warp_info_in_sm<CuDim3> (
-    dev, sm, UPDATE_CLUSTER_DIM_IN_SM, "cluster dimension", cuda_debugapi::get_cluster_dim,
-    [](uint32_t _dev, uint32_t _sm, uint32_t _wp, const CuDim3& _cluster_dim) {
-      cuda_state::warp_set_cluster_dim (_dev, _sm, _wp, _cluster_dim);
-    });
+      dev, sm, UPDATE_CLUSTER_DIM_IN_SM, "cluster dimension",
+      cuda_debugapi::get_cluster_dim,
+      [] (uint32_t _dev, uint32_t _sm, uint32_t _wp,
+	  const CuDim3 &_cluster_dim) {
+	cuda_state::warp_set_cluster_dim (_dev, _sm, _wp, _cluster_dim);
+      });
 }
 
 void
 cuda_remote_update_block_idx_in_sm (uint32_t dev, uint32_t sm)
 {
   cuda_remote_update_per_warp_info_in_sm<CuDim3> (
-    dev, sm, UPDATE_BLOCK_IDX_IN_SM, "block index", cuda_debugapi::read_block_idx,
-    [](uint32_t _dev, uint32_t _sm, uint32_t _wp, const CuDim3& _block_idx) {
-      cuda_state::warp_set_block_idx (_dev, _sm, _wp, _block_idx);
-    });
+      dev, sm, UPDATE_BLOCK_IDX_IN_SM, "block index",
+      cuda_debugapi::read_block_idx,
+      [] (uint32_t _dev, uint32_t _sm, uint32_t _wp,
+	  const CuDim3 &_block_idx) {
+	cuda_state::warp_set_block_idx (_dev, _sm, _wp, _block_idx);
+      });
 }
 
 void
 cuda_remote_update_thread_idx_in_warp (uint32_t dev, uint32_t sm, uint32_t wp)
 {
-  uint32_t valid_lanes_mask_c = cuda_state::warp_get_valid_lanes_mask (dev, sm, wp);
+  uint32_t valid_lanes_mask_c
+      = cuda_state::warp_get_valid_lanes_mask (dev, sm, wp);
   uint32_t num_lanes = cuda_state::device_get_num_lanes (dev);
 
   remote_callbacks.append_string ("qnv.");
   cuda_packet_type_t packet_type = UPDATE_THREAD_IDX_IN_WARP;
-  remote_callbacks.append_bin ((gdb_byte *) &packet_type, sizeof (packet_type));
+  remote_callbacks.append_bin ((gdb_byte *)&packet_type, sizeof (packet_type));
   remote_callbacks.append_separator ();
-  remote_callbacks.append_bin ((gdb_byte *) &dev, sizeof (dev));
+  remote_callbacks.append_bin ((gdb_byte *)&dev, sizeof (dev));
   remote_callbacks.append_separator ();
-  remote_callbacks.append_bin ((gdb_byte *) &sm, sizeof (sm));
+  remote_callbacks.append_bin ((gdb_byte *)&sm, sizeof (sm));
   remote_callbacks.append_separator ();
-  remote_callbacks.append_bin ((gdb_byte *) &wp, sizeof (wp));
+  remote_callbacks.append_bin ((gdb_byte *)&wp, sizeof (wp));
   remote_callbacks.append_separator ();
-  remote_callbacks.append_bin ((gdb_byte *) &num_lanes, sizeof (num_lanes));
+  remote_callbacks.append_bin ((gdb_byte *)&num_lanes, sizeof (num_lanes));
 
   remote_callbacks.send_request ();
 
   uint32_t valid_lanes_mask_s;
-  remote_callbacks.extract_bin ((gdb_byte *) &valid_lanes_mask_s, sizeof (valid_lanes_mask_s));
+  remote_callbacks.extract_bin ((gdb_byte *)&valid_lanes_mask_s,
+				sizeof (valid_lanes_mask_s));
   gdb_assert (valid_lanes_mask_s == valid_lanes_mask_c);
 
   for (uint32_t ln = 0; ln < num_lanes; ln++)
     {
-       if (cuda_state::lane_valid (dev, sm, wp, ln))
-         {
-	   CuDim3 thread_idx;
-	   remote_callbacks.extract_bin ((gdb_byte *) &thread_idx, sizeof (thread_idx));
-           cuda_state::lane_set_thread_idx (dev, sm, wp, ln, thread_idx);
-         }
+      if (cuda_state::lane_valid (dev, sm, wp, ln))
+	{
+	  CuDim3 thread_idx;
+	  remote_callbacks.extract_bin ((gdb_byte *)&thread_idx,
+					sizeof (thread_idx));
+	  cuda_state::lane_set_thread_idx (dev, sm, wp, ln, thread_idx);
+	}
     }
 
   CUDBGResult res;
-  remote_callbacks.extract_bin ((gdb_byte *) &res, sizeof (res));
+  remote_callbacks.extract_bin ((gdb_byte *)&res, sizeof (res));
   if (res != CUDBG_SUCCESS)
-    error (_("Error: Failed to read the thread index (error=%u).\n"), res);
+    error (_ ("Error: Failed to read the thread index (error=%u).\n"), res);
 }
 
 #ifdef __QNXTARGET__
 void
 cuda_remote_set_symbols (bool set_extra_symbols, bool *symbols_are_set)
 {
-  constexpr unsigned char CORE_SYMBOLS_COUNT = 13;
+  constexpr unsigned char CORE_SYMBOLS_COUNT = 11;
   constexpr unsigned char EXTRA_SYMBOLS_COUNT = 2;
   unsigned char symbols_count = CORE_SYMBOLS_COUNT;
 
@@ -423,7 +443,7 @@ cuda_remote_set_symbols (bool set_extra_symbols, bool *symbols_are_set)
   /* Remote side will also check for zeros, here we test only one symbol
      to avoid unnecessary back and forth with it.
      Sent symbols must be kept in sync with those in cuda_symbol_list[] */
-  CORE_ADDR address = cuda_get_symbol_address (_STRING_(CUDBG_IPC_FLAG_NAME));
+  CORE_ADDR address = cuda_get_symbol_address (_STRING_ (CUDBG_IPC_FLAG_NAME));
   if (address == 0)
     {
       return;
@@ -436,49 +456,49 @@ cuda_remote_set_symbols (bool set_extra_symbols, bool *symbols_are_set)
 
   remote_callbacks.append_string ("qnv.");
   cuda_packet_type_t packet_type = SET_SYMBOLS;
-  remote_callbacks.append_bin ((gdb_byte *) &packet_type, sizeof (packet_type));
+  remote_callbacks.append_bin ((gdb_byte *)&packet_type, sizeof (packet_type));
   remote_callbacks.append_separator ();
-  remote_callbacks.append_bin ((gdb_byte *) &symbols_count, sizeof (symbols_count));
+  remote_callbacks.append_bin ((gdb_byte *)&symbols_count,
+			       sizeof (symbols_count));
   remote_callbacks.append_separator ();
-  remote_callbacks.append_bin ((gdb_byte *) &address, sizeof (address));
+  remote_callbacks.append_bin ((gdb_byte *)&address, sizeof (address));
   remote_callbacks.append_separator ();
-  address = cuda_get_symbol_address (_STRING_(CUDBG_RPC_ENABLED));
-  remote_callbacks.append_bin ((gdb_byte *) &address, sizeof (address));
+  address = cuda_get_symbol_address (_STRING_ (CUDBG_RPC_ENABLED));
+  remote_callbacks.append_bin ((gdb_byte *)&address, sizeof (address));
   remote_callbacks.append_separator ();
-  address = cuda_get_symbol_address (_STRING_(CUDBG_APICLIENT_PID));
-  remote_callbacks.append_bin ((gdb_byte *) &address, sizeof (address));
+  address = cuda_get_symbol_address (_STRING_ (CUDBG_APICLIENT_PID));
+  remote_callbacks.append_bin ((gdb_byte *)&address, sizeof (address));
   remote_callbacks.append_separator ();
-  address = cuda_get_symbol_address (_STRING_(CUDBG_APICLIENT_REVISION));
-  remote_callbacks.append_bin ((gdb_byte *) &address, sizeof (address));
+  address = cuda_get_symbol_address (_STRING_ (CUDBG_APICLIENT_REVISION));
+  remote_callbacks.append_bin ((gdb_byte *)&address, sizeof (address));
   remote_callbacks.append_separator ();
-  address = cuda_get_symbol_address (_STRING_(CUDBG_SESSION_ID));
-  remote_callbacks.append_bin ((gdb_byte *) &address, sizeof (address));
+  address = cuda_get_symbol_address (_STRING_ (CUDBG_SESSION_ID));
+  remote_callbacks.append_bin ((gdb_byte *)&address, sizeof (address));
   remote_callbacks.append_separator ();
-  address = cuda_get_symbol_address (_STRING_(CUDBG_ATTACH_HANDLER_AVAILABLE));
-  remote_callbacks.append_bin ((gdb_byte *) &address, sizeof (address));
+  address
+      = cuda_get_symbol_address (_STRING_ (CUDBG_ATTACH_HANDLER_AVAILABLE));
+  remote_callbacks.append_bin ((gdb_byte *)&address, sizeof (address));
   remote_callbacks.append_separator ();
-  address = cuda_get_symbol_address (_STRING_(CUDBG_DEBUGGER_INITIALIZED));
-  remote_callbacks.append_bin ((gdb_byte *) &address, sizeof (address));
+  address = cuda_get_symbol_address (_STRING_ (CUDBG_DEBUGGER_INITIALIZED));
+  remote_callbacks.append_bin ((gdb_byte *)&address, sizeof (address));
   remote_callbacks.append_separator ();
-  address = cuda_get_symbol_address (_STRING_(CUDBG_REPORTED_DRIVER_API_ERROR_CODE));
-  remote_callbacks.append_bin ((gdb_byte *) &address, sizeof (address));
+  address = cuda_get_symbol_address (
+      _STRING_ (CUDBG_REPORTED_DRIVER_API_ERROR_CODE));
+  remote_callbacks.append_bin ((gdb_byte *)&address, sizeof (address));
   remote_callbacks.append_separator ();
-  address = cuda_get_symbol_address (_STRING_(CUDBG_REPORTED_DRIVER_INTERNAL_ERROR_CODE));
-  remote_callbacks.append_bin ((gdb_byte *) &address, sizeof (address));
+  address = cuda_get_symbol_address (
+      _STRING_ (CUDBG_REPORTED_DRIVER_INTERNAL_ERROR_CODE));
+  remote_callbacks.append_bin ((gdb_byte *)&address, sizeof (address));
   remote_callbacks.append_separator ();
   /* CUDBG_DETACH_SUSPENDED_DEVICES_MASK is deprecated */
-  address = cuda_get_symbol_address (_STRING_(CUDBG_DETACH_SUSPENDED_DEVICES_MASK));
-  remote_callbacks.append_bin ((gdb_byte *) &address, sizeof (address));
+  address = cuda_get_symbol_address (
+      _STRING_ (CUDBG_DETACH_SUSPENDED_DEVICES_MASK));
+  remote_callbacks.append_bin ((gdb_byte *)&address, sizeof (address));
   remote_callbacks.append_separator ();
-  /* CUDA MEMCHECK support is removed from CUDA GDB */
-  address = cuda_get_symbol_address (_STRING_(CUDBG_ENABLE_INTEGRATED_MEMCHECK));
-  remote_callbacks.append_bin ((gdb_byte *) &address, sizeof (address));
-  remote_callbacks.append_separator ();
-  address = cuda_get_symbol_address (_STRING_(CUDBG_ENABLE_LAUNCH_BLOCKING));
-  remote_callbacks.append_bin ((gdb_byte *) &address, sizeof (address));
-  remote_callbacks.append_separator ();
-  address = cuda_get_symbol_address (_STRING_(CUDBG_ENABLE_PREEMPTION_DEBUGGING));
-  remote_callbacks.append_bin ((gdb_byte *) &address, sizeof (address));
+  address = cuda_get_symbol_address (_STRING_ (CUDBG_ENABLE_LAUNCH_BLOCKING));
+  remote_callbacks.append_bin ((gdb_byte *)&address, sizeof (address));
+  /* No seperator for last entry */
+
   /* All new symbols should be placed under this condition to preserve
      compatibility between newer cuda-gdb and older cuda-gdbserver.
      Recent cuda-gdbserver binaries will gracefully handle more symbols
@@ -487,17 +507,20 @@ cuda_remote_set_symbols (bool set_extra_symbols, bool *symbols_are_set)
   if (set_extra_symbols)
     {
       remote_callbacks.append_separator ();
-      address = cuda_get_symbol_address (_STRING_(cudbgInjectionPath));
-      remote_callbacks.append_bin ((gdb_byte *) &address, sizeof (address));
+      address = cuda_get_symbol_address (_STRING_ (cudbgInjectionPath));
+      remote_callbacks.append_bin ((gdb_byte *)&address, sizeof (address));
       remote_callbacks.append_separator ();
-      address = cuda_get_symbol_address (_STRING_(CUDBG_DEBUGGER_CAPABILITIES));
-      remote_callbacks.append_bin ((gdb_byte *) &address, sizeof (address));
-      /* NOTE: When adding new symbols, add a call to append_separator and update `EXTRA_SYMBOLS_COUNT`. */
+      address
+	  = cuda_get_symbol_address (_STRING_ (CUDBG_DEBUGGER_CAPABILITIES));
+      remote_callbacks.append_bin ((gdb_byte *)&address, sizeof (address));
+      /* NOTE: When adding new symbols, add a call to append_separator and
+       * update `EXTRA_SYMBOLS_COUNT`. */
     }
 
   remote_callbacks.send_request ();
 
-  remote_callbacks.extract_bin ((gdb_byte *) symbols_are_set, sizeof (*symbols_are_set));
+  remote_callbacks.extract_bin ((gdb_byte *)symbols_are_set,
+				sizeof (*symbols_are_set));
 }
 #endif /* __QNXTARGET__ */
 
@@ -511,30 +534,29 @@ cuda_remote_initialize (CUDBGResult *get_debugger_api_res,
 {
   remote_callbacks.append_string ("qnv.");
   cuda_packet_type_t packet_type = INITIALIZE_TARGET;
-  remote_callbacks.append_bin ((gdb_byte *) &packet_type, sizeof (packet_type));
-  remote_callbacks.append_separator ();
-  bool preemption = cuda_options_software_preemption ();
-  remote_callbacks.append_bin ((gdb_byte *) &preemption, sizeof (preemption));
-  remote_callbacks.append_separator ();
-  /* CUDA MEMCHECK support is removed from CUDA GDB: this field is left to maintain
-   * the binary compatibility with legacy CUDA GDB server binaries */
-  bool memcheck = false;
-  remote_callbacks.append_bin ((gdb_byte *) &memcheck, sizeof (memcheck));
+  remote_callbacks.append_bin ((gdb_byte *)&packet_type, sizeof (packet_type));
   remote_callbacks.append_separator ();
   bool launch_blocking = cuda_options_launch_blocking ();
-  remote_callbacks.append_bin ((gdb_byte *) &launch_blocking, sizeof (launch_blocking));
+  remote_callbacks.append_bin ((gdb_byte *)&launch_blocking,
+			       sizeof (launch_blocking));
 
   remote_callbacks.send_request ();
 
-  remote_callbacks.extract_bin ((gdb_byte *) get_debugger_api_res, sizeof (*get_debugger_api_res));
-  remote_callbacks.extract_bin ((gdb_byte *) set_callback_api_res, sizeof (*set_callback_api_res));
-  remote_callbacks.extract_bin ((gdb_byte *) initialize_api_res, sizeof (*initialize_api_res));
-  remote_callbacks.extract_bin ((gdb_byte *) cuda_initialized, sizeof (*cuda_initialized));
-  remote_callbacks.extract_bin ((gdb_byte *) cuda_debugging_enabled, sizeof (*cuda_debugging_enabled));
-  remote_callbacks.extract_bin ((gdb_byte *) driver_is_compatible, sizeof (*driver_is_compatible));
-  remote_callbacks.extract_bin ((gdb_byte *) major, sizeof (*major));
-  remote_callbacks.extract_bin ((gdb_byte *) minor, sizeof (*minor));
-  remote_callbacks.extract_bin ((gdb_byte *) revision, sizeof (*revision));
+  remote_callbacks.extract_bin ((gdb_byte *)get_debugger_api_res,
+				sizeof (*get_debugger_api_res));
+  remote_callbacks.extract_bin ((gdb_byte *)set_callback_api_res,
+				sizeof (*set_callback_api_res));
+  remote_callbacks.extract_bin ((gdb_byte *)initialize_api_res,
+				sizeof (*initialize_api_res));
+  remote_callbacks.extract_bin ((gdb_byte *)cuda_initialized,
+				sizeof (*cuda_initialized));
+  remote_callbacks.extract_bin ((gdb_byte *)cuda_debugging_enabled,
+				sizeof (*cuda_debugging_enabled));
+  remote_callbacks.extract_bin ((gdb_byte *)driver_is_compatible,
+				sizeof (*driver_is_compatible));
+  remote_callbacks.extract_bin ((gdb_byte *)major, sizeof (*major));
+  remote_callbacks.extract_bin ((gdb_byte *)minor, sizeof (*minor));
+  remote_callbacks.extract_bin ((gdb_byte *)revision, sizeof (*revision));
 }
 
 void
@@ -545,22 +567,24 @@ cuda_remote_query_device_spec (uint32_t dev_id, uint32_t *num_sms,
 {
   remote_callbacks.append_string ("qnv.");
   cuda_packet_type_t packet_type = QUERY_DEVICE_SPEC;
-  remote_callbacks.append_bin ((gdb_byte *) &packet_type, sizeof (packet_type));
+  remote_callbacks.append_bin ((gdb_byte *)&packet_type, sizeof (packet_type));
   remote_callbacks.append_separator ();
-  remote_callbacks.append_bin ((gdb_byte *) &dev_id, sizeof (dev_id));
+  remote_callbacks.append_bin ((gdb_byte *)&dev_id, sizeof (dev_id));
 
   remote_callbacks.send_request ();
 
   CUDBGResult res;
-  remote_callbacks.extract_bin ((gdb_byte *) &res, sizeof (res));
+  remote_callbacks.extract_bin ((gdb_byte *)&res, sizeof (res));
   if (res != CUDBG_SUCCESS)
-    error (_("Error: Failed to read device specification (error=%u).\n"), res);
-  remote_callbacks.extract_bin ((gdb_byte *) num_sms, sizeof (*num_sms));
-  remote_callbacks.extract_bin ((gdb_byte *) num_warps, sizeof (*num_warps));
-  remote_callbacks.extract_bin ((gdb_byte *) num_lanes, sizeof (*num_lanes));
-  remote_callbacks.extract_bin ((gdb_byte *) num_registers, sizeof (*num_registers));
+    error (_ ("Error: Failed to read device specification (error=%u).\n"),
+	   res);
+  remote_callbacks.extract_bin ((gdb_byte *)num_sms, sizeof (*num_sms));
+  remote_callbacks.extract_bin ((gdb_byte *)num_warps, sizeof (*num_warps));
+  remote_callbacks.extract_bin ((gdb_byte *)num_lanes, sizeof (*num_lanes));
+  remote_callbacks.extract_bin ((gdb_byte *)num_registers,
+				sizeof (*num_registers));
   *dev_type = remote_callbacks.extract_string ();
-  *sm_type  = remote_callbacks.extract_string ();
+  *sm_type = remote_callbacks.extract_string ();
 }
 
 bool
@@ -568,15 +592,16 @@ cuda_remote_check_pending_sigint (ptid_t ptid)
 {
   remote_callbacks.append_string ("qnv.");
   cuda_packet_type_t packet_type = CHECK_PENDING_SIGINT;
-  remote_callbacks.append_bin ((gdb_byte *) &packet_type, sizeof (packet_type));
+  remote_callbacks.append_bin ((gdb_byte *)&packet_type, sizeof (packet_type));
 #ifdef __QNXTARGET__
-  /* Only send ptid for QNX targets since the server has trouble grabbing that */
+  /* Only send ptid for QNX targets since the server has trouble grabbing that
+   */
   remote_callbacks.append_separator ();
-  remote_callbacks.append_bin ((gdb_byte *) &ptid, sizeof (ptid));
+  remote_callbacks.append_bin ((gdb_byte *)&ptid, sizeof (ptid));
 #endif
 
   remote_callbacks.send_request ();
-  
+
   return cuda_remote_get_return_value ();
 }
 
@@ -586,7 +611,7 @@ cuda_remote_api_finalize ()
   cuda_remote_send_packet (API_FINALIZE);
 
   CUDBGResult res;
-  remote_callbacks.extract_bin ((gdb_byte *) &res, sizeof (res));
+  remote_callbacks.extract_bin ((gdb_byte *)&res, sizeof (res));
   return res;
 }
 
@@ -594,26 +619,29 @@ void
 cuda_remote_set_option ()
 {
   remote_callbacks.append_string ("qnv.");
-  cuda_packet_type_t packet_type = CHECK_PENDING_SIGINT;
-  remote_callbacks.append_bin ((gdb_byte *) &packet_type, sizeof (packet_type));
+  cuda_packet_type_t packet_type = SET_OPTION;
+  remote_callbacks.append_bin ((gdb_byte *)&packet_type, sizeof (packet_type));
   remote_callbacks.append_separator ();
   bool general_trace = cuda_options_debug_general ();
-  remote_callbacks.append_bin ((gdb_byte *) &general_trace, sizeof (general_trace));
+  remote_callbacks.append_bin ((gdb_byte *)&general_trace,
+			       sizeof (general_trace));
   remote_callbacks.append_separator ();
   bool libcudbg_trace = cuda_options_debug_libcudbg ();
-  remote_callbacks.append_bin ((gdb_byte *) &libcudbg_trace, sizeof (libcudbg_trace));
+  remote_callbacks.append_bin ((gdb_byte *)&libcudbg_trace,
+			       sizeof (libcudbg_trace));
   remote_callbacks.append_separator ();
   bool notifications_trace = cuda_options_debug_notifications ();
-  remote_callbacks.append_bin ((gdb_byte *) &notifications_trace, sizeof (notifications_trace));
+  remote_callbacks.append_bin ((gdb_byte *)&notifications_trace,
+			       sizeof (notifications_trace));
   remote_callbacks.append_separator ();
   bool notify_youngest = cuda_options_notify_youngest ();
-  remote_callbacks.append_bin ((gdb_byte *) &notify_youngest, sizeof (notify_youngest));
+  remote_callbacks.append_bin ((gdb_byte *)&notify_youngest,
+			       sizeof (notify_youngest));
+  remote_callbacks.append_separator ();
+  bool driver_logs = cuda_options_driver_logs_enabled ();
+  remote_callbacks.append_bin ((gdb_byte *)&driver_logs,
+             sizeof (driver_logs));
   remote_callbacks.append_separator ();
-  unsigned stop_signal = cuda_options_stop_signal ();
-  if (stop_signal == GDB_SIGNAL_TRAP)
-    remote_callbacks.append_string ("SIGTRAP");
-  else
-    remote_callbacks.append_string ("SIGURG");
 
   remote_callbacks.send_request ();
 }
@@ -621,9 +649,8 @@ cuda_remote_set_option ()
 void
 cuda_remote_query_trace_message ()
 {
-  if (!cuda_options_debug_general () &&
-      !cuda_options_debug_libcudbg () &&
-      !cuda_options_debug_notifications ())
+  if (!cuda_options_debug_general () && !cuda_options_debug_libcudbg ()
+      && !cuda_options_debug_notifications ())
     return;
 
   cuda_remote_send_packet (QUERY_TRACE_MESSAGE);
