@@ -2,16 +2,16 @@
  * NVIDIA CUDA Debugger CUDA-GDB
  * Copyright (C) 2021-2025 NVIDIA Corporation
  * Written by CUDA-GDB team at NVIDIA <cudatools@nvidia.com>
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 3 as
  * published by the Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
@@ -32,18 +32,20 @@
 
 static const char nvidia_copyright_currrent_year[] = "2025";
 
-const int cuda_major_version (void)
+const int
+cuda_major_version (void)
 {
   return CUDA_VERSION / 1000;
 }
 
-const int cuda_minor_version (void)
+const int
+cuda_minor_version (void)
 {
   return (CUDA_VERSION % 1000) / 10;
 }
 
-const char *cuda_current_year (void)
+const char *
+cuda_current_year (void)
 {
   return nvidia_copyright_currrent_year;
 }
-
