@@ -1,28 +1,28 @@
 /* NVIDIA CUDA Debugger CUDA-GDB
  * Copyright (C) 2007-2025 NVIDIA Corporation
  * Written by CUDA-GDB team at NVIDIA <cudatools@nvidia.com>
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 3 as
  * published by the Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "defs.h"
 
-#include <stdio.h>
-#include <stddef.h>
-#include <stdlib.h>
 #include <signal.h>
+#include <stddef.h>
+#include <stdio.h>
+#include <stdlib.h>
 #if !defined(__QNX__)
-# include <execinfo.h>
+#include <execinfo.h>
 #endif
 #include <dlfcn.h>
 #include <link.h>
@@ -43,13 +43,15 @@ struct bt_frame_info
   ptrdiff_t offset;
 };
 
-static void clean_frame_info_struct (struct bt_frame_info *btfi)
+static void
+clean_frame_info_struct (struct bt_frame_info *btfi)
 {
   free (btfi->obj);
   free (btfi->symbol);
 }
 
-static void exit_error (void)
+static void
+exit_error (void)
 {
   fprintf (stderr, "An error has occured while resolving the backtrace.\n");
   fflush (stderr);
@@ -57,14 +59,15 @@ static void exit_error (void)
   exit (1);
 }
 
-static void bfd_symbol_extraction (bfd *curr_exe)
+static void
+bfd_symbol_extraction (bfd *curr_exe)
 {
   long sym_size = bfd_get_symtab_upper_bound (curr_exe);
 
   if (sym_size <= 0)
     exit_error ();
 
-  symlist = (asymbol**)malloc (sym_size);
+  symlist = (asymbol **)malloc (sym_size);
 
   if (!symlist)
     exit_error ();
@@ -72,14 +75,16 @@ static void bfd_symbol_extraction (bfd *curr_exe)
   sym_count = bfd_canonicalize_symtab (curr_exe, symlist);
 }
 
-static void bfd_deinitialize (bfd *curr_exe)
+static void
+bfd_deinitialize (bfd *curr_exe)
 {
   if (curr_exe)
     bfd_close (curr_exe);
   free (symlist);
 }
 
-static bfd *bfd_initialize (void)
+static bfd *
+bfd_initialize (void)
 {
   bfd *curr_exe = NULL;
 
@@ -97,12 +102,13 @@ static bfd *bfd_initialize (void)
   return curr_exe;
 }
 
-/* Try to get the symbol name by locating the ELF symbols in memory and find the
- * closest symbol to our bt address. */
-static void resolve_with_bfd (struct bt_frame_info *btfi)
+/* Try to get the symbol name by locating the ELF symbols in memory and find
+ * the closest symbol to our bt address. */
+static void
+resolve_with_bfd (struct bt_frame_info *btfi)
 {
   long i;
-  symbol_info sym = {0};
+  symbol_info sym = { 0 };
   unsigned long target = 0;
 
   if ((uint64_t)btfi->addr < _r_debug.r_map->l_addr)
@@ -114,19 +120,19 @@ static void resolve_with_bfd (struct bt_frame_info *btfi)
   /* TODO: The search could be optimized, do we really want it? */
   for (i = 0; i < sym_count; ++i)
     {
-      symbol_info si = {0};
+      symbol_info si = { 0 };
 
       /* Discard section start labels (e.g _start and .text may coincide)*/
       if (symlist[i]->flags & BSF_SECTION_SYM)
-        continue;
+	continue;
 
       bfd_symbol_info (symlist[i], &si);
 
       if (!si.value || si.value > target)
-        continue;
+	continue;
 
       if (si.value > sym.value)
-        sym = si;
+	sym = si;
     }
 
   /* If we get past _end, the symbol belongs to another section (should have
@@ -140,9 +146,10 @@ static void resolve_with_bfd (struct bt_frame_info *btfi)
 
 /* Try to get the symbol name using dladdr(3) in case the symbol is exported in
  * the dynamic table. */
-static void resolve_with_dladdr (struct bt_frame_info *btfi)
+static void
+resolve_with_dladdr (struct bt_frame_info *btfi)
 {
-  Dl_info tmp = {0};
+  Dl_info tmp = { 0 };
 
   if (!btfi->addr)
     return;
@@ -157,10 +164,11 @@ static void resolve_with_dladdr (struct bt_frame_info *btfi)
     btfi->obj = strdup (tmp.dli_fname);
 
   if (tmp.dli_saddr)
-    btfi->offset = (char*)btfi->addr - (char*)tmp.dli_saddr;
+    btfi->offset = (char *)btfi->addr - (char *)tmp.dli_saddr;
 }
 
-static void resolve (struct bt_frame_info *btfi)
+static void
+resolve (struct bt_frame_info *btfi)
 {
   resolve_with_dladdr (btfi);
 
@@ -172,14 +180,15 @@ static void resolve (struct bt_frame_info *btfi)
       char *demangled = bfd_demangle (NULL, btfi->symbol, 0);
 
       if (!demangled)
-        return;
+	return;
 
       free (btfi->symbol);
       btfi->symbol = demangled;
     }
 }
 
-static void print_bt_info (struct bt_frame_info *btfi)
+static void
+print_bt_info (struct bt_frame_info *btfi)
 {
   size_t obj_len = btfi->obj ? strlen (btfi->obj) : 0;
 
@@ -196,21 +205,23 @@ static void print_bt_info (struct bt_frame_info *btfi)
   fflush (stderr);
 }
 
-void segv_handler (__attribute__((unused)) int signo)
+void
+segv_handler (__attribute__ ((unused)) int signo)
 {
   int i;
   int count = 0;
-  void *buffer[100] = {0};
+  void *buffer[100] = { 0 };
 
 #if !defined(__QNX__)
-  fprintf (stderr, "\ncuda-gdb has received a SIGSEGV and will attempt to get its own backtrace.\n\n");
+  fprintf (stderr, "\ncuda-gdb has received a SIGSEGV and will attempt to get "
+		   "its own backtrace.\n\n");
 
   count = backtrace (buffer, 100);
   bfd *curr = bfd_initialize ();
 
   for (i = 0; i < count; ++i)
     {
-      struct bt_frame_info btfi = {.addr = buffer[i]};
+      struct bt_frame_info btfi = { .addr = buffer[i] };
 
       resolve (&btfi);
       print_bt_info (&btfi);
