@@ -18,15 +18,13 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* NVIDIA CUDA Debugger CUDA-GDB
-   Copyright (C) 2007-2024 NVIDIA Corporation
+   Copyright (C) 2007-2025 NVIDIA Corporation
    Modified from the original GDB file referenced above by the CUDA-GDB
    team at NVIDIA <cudatools@nvidia.com>. */
 
 #if !defined (FRAME_H)
 #define FRAME_H 1
 
-#include "frame-info.h"
-
 /* The following is the intended naming schema for frame functions.
    It isn't 100% consistent, but it is approaching that.  Frame naming
    schema:
@@ -76,9 +74,10 @@
 
    */
 
-#include "language.h"
 #include "cli/cli-option.h"
+#include "frame-id.h"
 #include "gdbsupport/common-debug.h"
+#include "gdbsupport/intrusive_list.h"
 
 struct symtab_and_line;
 struct frame_unwind;
@@ -91,7 +90,6 @@ struct frame_print_options;
 
 /* The frame object.  */
 
-class frame_info_ptr;
 
 /* Save and restore the currently selected frame.  */
 
@@ -166,6 +164,16 @@ extern struct frame_id
    as the special identifier address are set to indicate wild cards.  */
 extern struct frame_id frame_id_build_wild (CORE_ADDR stack_addr);
 
+/* Construct a frame ID for a sentinel frame.
+
+   If either STACK_ADDR or CODE_ADDR is not 0, the ID represents a sentinel
+   frame for a user-created frame.  STACK_ADDR and CODE_ADDR are the addresses
+   used to create the frame.
+
+   If STACK_ADDR and CODE_ADDR are both 0, the ID represents a regular sentinel
+   frame (i.e. the "next" frame of the target's current frame).  */
+extern frame_id frame_id_build_sentinel (CORE_ADDR stack_addr, CORE_ADDR code_addr);
+
 /* Returns true when L is a valid frame.  */
 extern bool frame_id_p (frame_id l);
 
@@ -200,6 +208,208 @@ enum frame_type
   SENTINEL_FRAME
 };
 
+/* Return a string representation of TYPE.  */
+
+extern const char *frame_type_str (frame_type type);
+
+/* A wrapper for "frame_info *".  frame_info objects are invalidated
+   whenever reinit_frame_cache is called.  This class arranges to
+   invalidate the pointer when appropriate.  This is done to help
+   detect a GDB bug that was relatively common.
+
+   A small amount of code must still operate on raw pointers, so a
+   "get" method is provided.  However, you should normally not use
+   this in new code.  */
+
+class frame_info_ptr : public intrusive_list_node<frame_info_ptr>
+{
+public:
+  /* Create a frame_info_ptr from a raw pointer.  */
+  explicit frame_info_ptr (struct frame_info *ptr);
+
+  /* Create a null frame_info_ptr.  */
+  frame_info_ptr ()
+  {
+    frame_list.push_back (*this);
+  }
+
+  frame_info_ptr (std::nullptr_t)
+  {
+    frame_list.push_back (*this);
+  }
+
+  frame_info_ptr (const frame_info_ptr &other)
+    : m_ptr (other.m_ptr),
+      m_cached_id (other.m_cached_id),
+      m_cached_level (other.m_cached_level)
+  {
+    frame_list.push_back (*this);
+  }
+
+  frame_info_ptr (frame_info_ptr &&other)
+    : m_ptr (other.m_ptr),
+      m_cached_id (other.m_cached_id),
+      m_cached_level (other.m_cached_level)
+  {
+    other.m_ptr = nullptr;
+    other.m_cached_id = null_frame_id;
+    other.m_cached_level = invalid_level;
+    frame_list.push_back (*this);
+  }
+
+  ~frame_info_ptr ()
+  {
+    /* If this node has static storage, it should be be deleted before
+       frame_list.  */
+    frame_list.erase (frame_list.iterator_to (*this));
+  }
+
+  frame_info_ptr &operator= (const frame_info_ptr &other)
+  {
+    m_ptr = other.m_ptr;
+    m_cached_id = other.m_cached_id;
+    m_cached_level = other.m_cached_level;
+    return *this;
+  }
+
+  frame_info_ptr &operator= (std::nullptr_t)
+  {
+    m_ptr = nullptr;
+    m_cached_id = null_frame_id;
+    m_cached_level = invalid_level;
+    return *this;
+  }
+
+  frame_info_ptr &operator= (frame_info_ptr &&other)
+  {
+    m_ptr = other.m_ptr;
+    m_cached_id = other.m_cached_id;
+    m_cached_level = other.m_cached_level;
+    other.m_ptr = nullptr;
+    other.m_cached_id = null_frame_id;
+    other.m_cached_level = invalid_level;
+    return *this;
+  }
+
+  frame_info *operator-> () const
+  { return this->reinflate (); }
+
+  /* Fetch the underlying pointer.  Note that new code should
+     generally not use this -- avoid it if at all possible.  */
+  frame_info *get () const
+  {
+    if (this->is_null ())
+      return nullptr;
+
+    return this->reinflate ();
+  }
+
+  /* Return true if this object is empty (does not wrap a frame_info
+     object).  */
+
+  bool is_null () const
+  {
+    return m_cached_level == this->invalid_level;
+  };
+
+  /* This exists for compatibility with pre-existing code that checked
+     a "frame_info *" using "!".  */
+  bool operator! () const
+  {
+    return this->is_null ();
+  }
+
+  /* This exists for compatibility with pre-existing code that checked
+     a "frame_info *" like "if (ptr)".  */
+  explicit operator bool () const
+  {
+    return !this->is_null ();
+  }
+
+  /* Invalidate this pointer.  */
+  void invalidate ()
+  {
+    m_ptr = nullptr;
+  }
+
+private:
+  /* We sometimes need to construct frame_info_ptr objects around the
+     sentinel_frame, which has level -1.  Therefore, make the invalid frame
+     level value -2.  */
+  static constexpr int invalid_level = -2;
+
+  /* Use the cached frame level and id to reinflate the pointer, and return
+     it.  */
+  frame_info *reinflate () const;
+
+  /* The underlying pointer.  */
+  mutable frame_info *m_ptr = nullptr;
+
+  /* The frame_id of the underlying pointer.
+
+     For the current target frames (frames with level 0, obtained through
+     get_current_frame), we don't save the frame id, we leave it at
+     null_frame_id.  For user-created frames (also with level 0, but created
+     with create_new_frame), we do save the id.  */
+  frame_id m_cached_id = null_frame_id;
+
+  /* The frame level of the underlying pointer.  */
+  int m_cached_level = invalid_level;
+
+  /* All frame_info_ptr objects are kept on an intrusive list.
+     This keeps their construction and destruction costs
+     reasonably small.  */
+  static intrusive_list<frame_info_ptr> frame_list;
+
+  /* A friend so it can invalidate the pointers.  */
+  friend void reinit_frame_cache ();
+};
+
+static inline bool
+operator== (const frame_info *self, const frame_info_ptr &other)
+{
+  if (self == nullptr || other.is_null ())
+    return self == nullptr && other.is_null ();
+
+  return self == other.get ();
+}
+
+static inline bool
+operator== (const frame_info_ptr &self, const frame_info_ptr &other)
+{
+  if (self.is_null () || other.is_null ())
+    return self.is_null () && other.is_null ();
+
+  return self.get () == other.get ();
+}
+
+static inline bool
+operator== (const frame_info_ptr &self, const frame_info *other)
+{
+  if (self.is_null () || other == nullptr)
+    return self.is_null () && other == nullptr;
+
+  return self.get () == other;
+}
+
+static inline bool
+operator!= (const frame_info *self, const frame_info_ptr &other)
+{
+  return !(self == other);
+}
+
+static inline bool
+operator!= (const frame_info_ptr &self, const frame_info_ptr &other)
+{
+  return !(self == other);
+}
+
+static inline bool
+operator!= (const frame_info_ptr &self, const frame_info *other)
+{
+  return !(self == other);
+}
+
 /* For every stopped thread, GDB tracks two frames: current and
    selected.  Current frame is the inner most frame of the selected
    thread.  Selected frame is the one being examined by the GDB
@@ -390,7 +600,7 @@ void set_current_sal_from_frame (frame_info_ptr);
 
 extern CORE_ADDR get_frame_base (frame_info_ptr);
 
-/* Return the per-frame unique identifer.  Can be used to relocate a
+/* Return the per-frame unique identifier.  Can be used to relocate a
    frame after a frame cache flush (and other similar operations).  If
    FI is NULL, return the null_frame_id.  */
 extern struct frame_id get_frame_id (frame_info_ptr fi);
@@ -438,6 +648,13 @@ class address_space;
 /* Return the frame's address space.  */
 extern const address_space *get_frame_address_space (frame_info_ptr);
 
+/* A frame may have a "static link".  That is, in some languages, a
+   nested function may have access to variables from the enclosing
+   block and frame.  This function looks for a frame's static link.
+   If found, returns the corresponding frame; otherwise, returns a
+   null frame_info_ptr.  */
+extern frame_info_ptr frame_follow_static_link (frame_info_ptr frame);
+
 /* For frames where we can not unwind further, describe why.  */
 
 enum unwind_stop_reason
@@ -739,7 +956,7 @@ struct frame_arg
   struct value *val = nullptr;
 
   /* String containing the error message, it is more usually NULL indicating no
-     error occured reading this parameter.  */
+     error occurred reading this parameter.  */
   gdb::unique_xmalloc_ptr<char> error;
 
   /* One of the print_entry_values_* entries as appropriate specifically for
