@@ -354,7 +354,7 @@ nto_cmp_host_to_target_word (bfd *abfd, CORE_ADDR host_addr,
   unsigned host_word, target_word;
 
   if ( ( bfd_seek(abfd, host_addr, SEEK_SET) != 0 )
-      || ( bfd_bread ((gdb_byte*)&host_word, sizeof (host_word), abfd)
+      || ( bfd_read ((gdb_byte*)&host_word, sizeof (host_word), abfd)
           != sizeof (host_word) ) )
     return -1;
   if (target_read_memory(target_addr, (gdb_byte*)&target_word,
@@ -580,12 +580,22 @@ nto_find_and_open_solib (const char *solib, unsigned o_flags,
     {
       // solib came with path attached, try that one first
       nto_trace(1)("  trying %s\n", solib);
+#ifdef NVIDIA_BUGFIX
+      /* CUDA - Silence warning */
+      scoped_fd r = gdb_open_cloexec (solib, o_flags, 0);
+      if (r.get () >= 0)
+	{
+	  *temp_pathname = gdb_realpath(solib);
+	  return r.get ();
+	}
+#else
       scoped_fd ret = gdb_open_cloexec (solib, o_flags, 0);
       if (ret.get () >= 0)
 	{
 	  *temp_pathname = gdb_realpath(solib);
 	  return ret.get ();
 	}
+#endif
     }
 
   xsnprintf (buf, plen, PATH_FMT, arch_path, arch_path, arch_path,
