@@ -46,12 +46,11 @@ extern CUDBGResult set_callback_api_res;
 extern struct cuda_sym cuda_symbol_list[];
 extern bool cuda_syms_looked_up;
 extern bool cuda_launch_blocking;
-extern bool cuda_software_preemption;
 extern bool cuda_debug_general;
 extern bool cuda_debug_libcudbg;
 extern bool cuda_debug_notifications;
 extern bool cuda_notify_youngest;
-extern unsigned cuda_stop_signal;
+extern bool cuda_driver_logs;
 
 extern ptid_t cuda_last_ptid;
 extern struct target_waitstatus cuda_last_ws;
@@ -82,6 +81,8 @@ void cuda_cleanup (void);
 bool cuda_inferior_in_debug_mode (void);
 bool cuda_initialize_target ();
 
+void cuda_set_driver_logging (bool enable);
+
 CORE_ADDR cuda_get_symbol_address_from_cache (const char *name);
 
 int  cuda_get_debugger_api (void);
@@ -96,8 +97,6 @@ void cuda_trace (const char *fmt, ...);
 
 bool cuda_options_launch_blocking (void);
 
-bool cuda_options_software_preemption (void);
-
 bool cuda_options_debug_general (void);
 
 bool cuda_options_debug_libcudbg (void);
@@ -106,6 +105,8 @@ bool cuda_options_debug_notifications (void);
 
 bool cuda_options_notify_youngest (void);
 
+bool cuda_options_driver_logs (void);
+
 bool cuda_check_pending_sigint (ptid_t ptid);
 
 bool cuda_platform_supports_tid (void);
@@ -117,6 +118,4 @@ void        cuda_gdb_session_destroy (void);
 const char *cuda_gdb_session_get_dir (void);
 uint32_t    cuda_gdb_session_get_id (void);
 
-/* SIGTRAP vs SIGURG option */
-unsigned cuda_options_stop_signal (void);
 #endif
