@@ -605,7 +605,8 @@ extern "C" {
 
   // ----------- enclosed eigenvalues
 
-  CUSOLVER_DEPRECATED_ cusolverStatus_t CUSOLVERAPI cusolverSpScsreigsHost(
+
+  CUSOLVER_DEPRECATED(cuDSS) cusolverStatus_t CUSOLVERAPI cusolverSpScsreigsHost(
     cusolverSpHandle_t       handle,
     int                      m,
     int                      nnz,
@@ -617,7 +618,7 @@ extern "C" {
     cuComplex                right_upper_corner,
     int *                    num_eigs);
 
-  CUSOLVER_DEPRECATED_ cusolverStatus_t CUSOLVERAPI cusolverSpDcsreigsHost(
+  CUSOLVER_DEPRECATED(cuDSS) cusolverStatus_t CUSOLVERAPI cusolverSpDcsreigsHost(
     cusolverSpHandle_t       handle,
     int                      m,
     int                      nnz,
@@ -629,7 +630,7 @@ extern "C" {
     cuDoubleComplex          right_upper_corner,
     int *                    num_eigs);
 
-  CUSOLVER_DEPRECATED_ cusolverStatus_t CUSOLVERAPI cusolverSpCcsreigsHost(
+  CUSOLVER_DEPRECATED(cuDSS) cusolverStatus_t CUSOLVERAPI cusolverSpCcsreigsHost(
     cusolverSpHandle_t       handle,
     int                      m,
     int                      nnz,
@@ -641,7 +642,7 @@ extern "C" {
     cuComplex                right_upper_corner,
     int *                    num_eigs);
 
-  CUSOLVER_DEPRECATED_ cusolverStatus_t CUSOLVERAPI cusolverSpZcsreigsHost(
+  CUSOLVER_DEPRECATED(cuDSS) cusolverStatus_t CUSOLVERAPI cusolverSpZcsreigsHost(
     cusolverSpHandle_t       handle,
     int                      m,
     int                      nnz,
